@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.21 2003/05/19 11:08:13 gman Exp $ */
+/* $Id: dict.c,v 1.22 2003/05/19 19:46:00 merchan Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -673,7 +673,7 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
         dict_disconnect (context);
         dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_MESSAGE_ERROR,
-                                         GTK_BUTTONS_CLOSE,
+                                         GTK_BUTTONS_OK,
                                          _("A serious error occured. Please check that your server and port are correct. For reference the default server is dict.org and the port 2628"));
         g_signal_connect_swapped (GTK_OBJECT (dialog), "response",
                                   G_CALLBACK (gtk_widget_destroy),
