@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.34 2003/05/18 17:15:52 dcransto Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.38 2003/07/22 01:04:09 dcransto Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -33,17 +33,6 @@ enum {
     LAST_SIGNAL
 };
 
-static gchar *typeface_sel_names[NUM_TYPEFACES] = {
-    N_("Headword:"),
-    N_("Sub-number:"),
-    N_("Pronunciation:"),
-    N_("Etymology:"),
-    N_("Part of speech:"),
-    N_("Example:"),
-    N_("Main body:"),
-    N_("Cross-reference:")
-};
-
 #define NUM_TYPEFACE_ROWS 4
 #define NUM_TYPEFACE_COLS 2
 
@@ -64,8 +53,6 @@ static void pref_dialog_add_strat   (GDictPrefDialog *pref_dialog,
                                      gchar *strat, gchar *desc);
 static void pref_dialog_reset_db    (GDictPrefDialog *pref_dialog);
 static void pref_dialog_reset_strat (GDictPrefDialog *pref_dialog);
-static gint pref_dialog_update_pref (GDictPrefDialog *pref_dialog,
-                                     gboolean save_prefs);
 
 static void pref_set_strat_cb       (GtkWidget *widget, gpointer data);
 static void pref_set_db_cb          (GtkWidget *widget, gpointer data);
@@ -79,9 +66,6 @@ static void pref_status_cb          (dict_command_t *command,
 static void pref_data_cb            (dict_command_t *command, dict_res_t *res,
                                      gpointer data);
 
-static void pref_dialog_ok_cb       (GtkWidget *widget, gpointer data);
-static void pref_dialog_apply_cb    (GtkWidget *widget, gpointer data);
-static void pref_dialog_close_cb    (GtkWidget *widget, gpointer data);
 static void phelp_cb		    (GtkDialog *dialog, gint response);
 static void response_cb		    (GtkDialog *dialog, gint response);
 static gboolean	set_server_cb 	    (GtkWidget *widget, GdkEventFocus *event, gpointer data);
@@ -174,11 +158,10 @@ gdict_pref_dialog_class_init (GDictPrefDialogClass *class)
 static void
 create_dialog (GDictPrefDialog *pref_dialog)
 {
-    GtkWidget *server_label, *port_label, *alignment;
-    GtkWidget *vbox, *table;
+    GtkWidget *server_label, *port_label;
+    GtkWidget *vbox;
     GtkWidget *button;    
     gchar *port_str;
-    gint i;
     
     pref_dialog->database = gdict_pref.database;
     pref_dialog->dfl_strat = gdict_pref.dfl_strat;
@@ -187,7 +170,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
     gtk_window_set_policy (GTK_WINDOW (pref_dialog), FALSE, FALSE, FALSE);    
     gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
     vbox = GTK_DIALOG (pref_dialog)->vbox;
-
+    gtk_box_set_spacing (GTK_BOX (vbox), 2);
     
     pref_dialog->table = GTK_TABLE (gtk_table_new (5, 3, FALSE));
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), GTK_WIDGET (pref_dialog->table), TRUE, TRUE, 0);
@@ -201,6 +184,8 @@ create_dialog (GDictPrefDialog *pref_dialog)
     		      G_CALLBACK (smart_lookup_cb), pref_dialog);
     gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (pref_dialog->smart_lookup_btn),
     			       1, 3, 2, 3);
+    if ( ! gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/smart", NULL))
+	    gtk_widget_set_sensitive (GTK_WIDGET (pref_dialog->smart_lookup_btn), FALSE);
     
     pref_dialog->server_entry = GTK_ENTRY (gtk_entry_new ());			       
     gtk_table_attach (pref_dialog->table, 
@@ -230,6 +215,12 @@ create_dialog (GDictPrefDialog *pref_dialog)
     if( gail_loaded )
         add_atk_namedesc(GTK_WIDGET(button), NULL, _("Reset server to default"));
 
+    if ( ! gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/server", NULL)) {
+	    gtk_widget_set_sensitive (GTK_WIDGET (pref_dialog->server_entry), FALSE);
+	    gtk_widget_set_sensitive (server_label, FALSE);
+	    gtk_widget_set_sensitive (button, FALSE);
+    }
+
     port_label = gtk_label_new_with_mnemonic (_("_Port:"));
     gtk_table_attach_defaults (pref_dialog->table, port_label, 0, 1, 1, 2);
     gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_LEFT);
@@ -267,6 +258,12 @@ create_dialog (GDictPrefDialog *pref_dialog)
 
     }
 
+    if ( ! gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/port", NULL)) {
+	    gtk_widget_set_sensitive (GTK_WIDGET (pref_dialog->port_entry), FALSE);
+	    gtk_widget_set_sensitive (port_label, FALSE);
+	    gtk_widget_set_sensitive (button, FALSE);
+    }
+
     db_label = gtk_label_new_with_mnemonic (_("_Database:"));
     gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment (GTK_MISC (db_label), 0, 0.5);
@@ -318,7 +315,6 @@ GtkWidget *
 gdict_pref_dialog_new (dict_context_t *context) 
 {
     GDictPrefDialog *pref_dialog;
-    GtkLabel *label;
     
     /* g_return_val_if_fail (context != NULL, NULL); */
     /* the above is commented out because it prints ugly debug messages
@@ -439,7 +435,6 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
 
 static void
 pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
-    GtkWidget *error_label, *alignment;
 
     if (pref_dialog->get_db_cmd)
       dict_command_destroy (pref_dialog->get_db_cmd);
@@ -492,7 +487,6 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog) {
 
 static void
 pref_dialog_reset_strat (GDictPrefDialog *pref_dialog) {
-    GtkWidget *error_label, *alignment;
 
     if (pref_dialog->get_strat_cmd)
 	dict_command_destroy (pref_dialog->get_strat_cmd);
@@ -556,7 +550,7 @@ pref_error_cb (dict_command_t *command, DictStatusCode code,
         GtkWidget *dialog;
         dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                   	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  	 "%s", message, NULL); 
+                                  	 "%s", message); 
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
     }
@@ -601,6 +595,7 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
     GtkOptionMenu *option_menu = NULL;
     GtkMenu *use_menu = NULL;
     gint row = 0;
+    gboolean writable;
     
     g_return_if_fail (data != NULL);
     g_return_if_fail (IS_GDICT_PREF_DIALOG (data));
@@ -637,6 +632,11 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
                 add_atk_relation( GTK_WIDGET (option_menu), db_label, ATK_RELATION_LABELLED_BY);
 
             }
+
+            writable = gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/database", NULL);
+
+	    gtk_widget_set_sensitive (db_label, writable);
+	    gtk_widget_set_sensitive (GTK_WIDGET (option_menu), writable);
         }
         else if (command->cmd == C_SHOW_STRAT)
         {
@@ -649,6 +649,11 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
                 add_atk_relation( GTK_WIDGET (option_menu), strat_label, ATK_RELATION_LABELLED_BY);
 
             }
+
+            writable = gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/strategy", NULL);
+
+	    gtk_widget_set_sensitive (strat_label, writable);
+	    gtk_widget_set_sensitive (GTK_WIDGET (option_menu), writable);
         }
     }
 }
@@ -700,7 +705,6 @@ set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
     GDictPrefDialog *pref_dialog = data;
     gchar *port;
-    gint old_port;
     
     port = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->port_entry), 0, -1);
     
@@ -750,7 +754,6 @@ set_default_port (GtkButton *button, gpointer data)
 static void 
 smart_lookup_cb	(GtkToggleButton *toggle, gpointer data)
 {
-    GDictPrefDialog *pref_dialog = data;
     gboolean toggled;
     
     toggled = gtk_toggle_button_get_active (toggle);
@@ -773,7 +776,7 @@ phelp_cb    (GtkDialog *dialog, gint response)
 		msg_dialog = gtk_message_dialog_new (GTK_WINDOW(dialog),
 						     GTK_DIALOG_DESTROY_WITH_PARENT,
 						     GTK_MESSAGE_ERROR,
-						     GTK_BUTTONS_CLOSE,
+						     GTK_BUTTONS_OK,
 						     ("There was an error displaying help: \n%s"),
 						     error->message);
 
